@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Dict, Any
+from typing import Dict, Any, Optional
 
 from pypsql_api.config.types import Session
 from pypsql_api.ext.handlers import AuthHandler, QueryHandler, ExtendedQueryHandler
@@ -24,6 +24,11 @@ class Context:
     prepared_statements: Dict[str, PreparedStatement]
     portals: Dict[str, Portal]
 
+    key_file: Optional[str]
+    cert_file: Optional[str]
+
+    socket: Optional[Any]
+
     def update_mem(self, k, v):
         return Context(input=self.input, output=self.output,
                        session=self.session,
@@ -32,4 +37,7 @@ class Context:
                        extended_query_handler=self.extended_query_handler,
                        mem={**self.mem, **{k: v}},
                        prepared_statements=self.prepared_statements,
-                       portals=self.portals)
+                       portals=self.portals,
+                       key_file=self.key_file,
+                       cert_file=self.cert_file,
+                       socket=self.socket)
