@@ -81,6 +81,7 @@ Note on any back error
      Send ErrorResponse and read till Sync found
      then send ReadyForQuery
 """
+import logging
 import traceback
 
 from pandas import DataFrame
@@ -102,28 +103,40 @@ def process_parse_command(context: Context):
     :param context:
     :return:
     """
-    msg = context.mem.get('message', None)
+    logging.info("#################  Handler Parse  ####################")
+    try:
+        msg = context.mem.get('message', None)
 
-    if not isinstance(msg, ParseMessage):
-        raise Exception(f"ParseMessage expected but got: {msg}")
+        if not isinstance(msg, ParseMessage):
+            raise Exception(f"ParseMessage expected but got: {msg}")
 
-    if msg.query:
-        msg.query = msg.query.replace('OPERATOR(pg_catalog.~)', '=') \
-            .replace('~', '=')
+        if msg.query:
+            msg.query = msg.query.replace('OPERATOR(pg_catalog.~)', '=') \
+                .replace('~', '=')
 
-        handler = context.extended_query_handler
-        resp, error_msg = handler.parse(session=context.session, msg=msg)
+            handler = context.extended_query_handler
 
-        if isinstance(resp, PreparedStatement):
-            context.prepared_statements[msg.name] = resp
-            ParseComplete().write(context.output)
+            try:
+                resp, error_msg = handler.parse(session=context.session, msg=msg)
+
+                logging.info(resp)
+
+                if isinstance(resp, PreparedStatement):
+                    context.prepared_statements[msg.name] = resp
+                    ParseComplete().write(context.output)
+                    logging.info(f"Have prepared statement: {context.prepared_statements}")
+                    return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
+                else:
+                    logging.error(f"Error: {resp} {error_msg}")
+                    return context, Names.CLOSE
+            except Exception as e:
+                log_exception(e)
+                return context, Names.CLOSE
 
-            return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
         else:
-            print(f"Error: {resp} {error_msg}")
-            return context, Names.ERROR
-    else:
-        return context, Names.ERROR
+            return context, Names.CLOSE
+    finally:
+        logging.info("######################################################")
 
 
 def process_bind_command(context: Context):
@@ -181,7 +194,6 @@ def process_bind_command(context: Context):
 def process_execute_command(context: Context):
     msg = context.mem.get('message', None)
 
-
     if not isinstance(msg, ExecuteMessage):
         if isinstance(msg, Sync):
             return context, Names.SYNC
@@ -256,21 +268,24 @@ def write_extended_data_frame_response(context: Context):
         raise Exception("We expect a execution_portal instance here")
 
     try:
-        rows = DataFrameDataRows(df=execution.df,
-                                 offset=execution.offset,
-                                 max_rows=execution.max_rows).write(context.output)
-        context.output.flush()
-
-        df_rows = len(execution.df.index)
-
-        read_all_rows = rows + execution.offset >= df_rows
-
-        if rows == 0:
+        if execution.df is None:
             EmptyQueryResponse().write(context.output)
-        elif read_all_rows:
-            CommandComplete(f"SELECT {df_rows}").write(context.output)
-        elif rows < execution.max_rows:
-            PortalSuspended().write(context.output)
+        else:
+            rows = DataFrameDataRows(df=execution.df,
+                                     offset=execution.offset,
+                                     max_rows=execution.max_rows).write(context.output)
+            context.output.flush()
+
+            df_rows = len(execution.df.index)
+
+            read_all_rows = rows + execution.offset >= df_rows
+
+            if rows == 0:
+                EmptyQueryResponse().write(context.output)
+            elif read_all_rows:
+                CommandComplete(f"SELECT {df_rows}").write(context.output)
+            elif rows < execution.max_rows:
+                PortalSuspended().write(context.output)
 
         return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
 
@@ -291,11 +306,19 @@ def describe_statement_or_portal(context: Context):
         if msg.t == 'S':
             prepared_statement = context.prepared_statements[msg.name]
             print(f"Describe {prepared_statement}")
+            logging.error(f"Describe on prepared statement is not implemented yet")
+            return context, Names.CLOSE
         else:
             portal = context.portals[msg.name]
             print(f"Describe {portal}")
             print(f"Writing DataFrameRowDescription")
-            DataFrameRowDescription(df=portal.row_description).write(context.output)
+            if portal.row_description is None:
+                logging.error(f"Empty row description for portal {portal.row_description}")
+
+                return write_extended_empty_response(context)
+            else:
+                DataFrameRowDescription(df=portal.row_description).write(context.output)
+
             context.output.flush()
 
         return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
